Pass class

Implementers

Constructors

Pass()

Properties

camera ↔ Camera
getter/setter pair
clear ↔ bool
getter/setter pair
enabled ↔ bool
getter/setter pair
fsQuad ↔ FullScreenQuad
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
material ↔ Material
getter/setter pair
needsSwap ↔ bool
getter/setter pair
renderToScreen ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scene ↔ Object3D
getter/setter pair
uniforms ↔ Map<String, dynamic>
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Renderer renderer, RenderTarget writeBuffer, RenderTarget readBuffer, {double? deltaTime, bool? maskActive}) → void
setProperty(String key, dynamic newValue) → void
setSize(int width, int height) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited